@@ -1,6 +1,6 @@
 /* NickServ core functions
  *
- * (C) 2003-2024 Anope Team
+ * (C) 2003-2025 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -162,7 +162,7 @@ class CommandNSGroup : public Command
 			source.Reply(_("There are too many nicks in your group."));
 		else if (source.GetNick().length() <= guestnick.length() + 7 &&
 			source.GetNick().length() >= guestnick.length() + 1 &&
-			!source.GetNick().find_ci(guestnick) && !source.GetNick().substr(guestnick.length()).find_first_not_of("1234567890"))
+			!source.GetNick().find_ci(guestnick) && source.GetNick().substr(guestnick.length()).find_first_not_of("1234567890") == Anope::string::npos)
 		{
 			source.Reply(NICK_CANNOT_BE_REGISTERED, source.GetNick().c_str());
 		}
