@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2003-2024 Anope Team
+ * (C) 2003-2025 Anope Team
  * Contact us at team@anope.org
  *
  * Please read COPYING and README for further details.
@@ -18,6 +18,7 @@
 #include "modules/suspend.h"
 #include "modules/os_forbid.h"
 #include "modules/cs_entrymsg.h"
+#include "modules/set_misc.h"
 
 #define READ(x) \
 if (true) \
@@ -473,10 +474,24 @@ static void LoadNicks()
 
 			uint32_t u32;
 			READ(read_uint32(&u32, f));
-			//nc->icq = u32;
+			ExtensibleRef<MiscData> icqref("ns_set_misc:ICQ");
+			if (icqref && u32 > 0)
+			{
+				MiscData *data = icqref->Set(nc);
+				data->object = nc->display;
+				data->name = "ns_set_misc:ICQ";
+				data->data = stringify(u32);
+			}
 
 			READ(read_string(buffer, f));
-			//nc->url = buffer;
+			ExtensibleRef<MiscData> urlref("ns_set_misc:URL");
+			if (urlref && !buffer.empty())
+			{
+				MiscData *data = icqref->Set(nc);
+				data->object = nc->display;
+				data->name = "ns_set_misc:URL";
+				data->data = buffer;
+			}
 
 			READ(read_uint32(&u32, f));
 			if (u32 & OLD_NI_KILLPROTECT)
